==> roughpy-0.1.1.tar.gz: roughpy-0.1.1/platform/src/devices/event.cpp <==
// Copyright (c) 2023 the RoughPy Developers. All rights reserved.
//
// Redistribution and use in source and binary forms, with or without modification,
// are permitted provided that the following conditions are met:
//
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright notice,
// this list of conditions and the following disclaimer in the documentation
// and/or other materials provided with the distribution.
//
// 3. Neither the name of the copyright holder nor the names of its contributors
// may be used to endorse or promote products derived from this software without
// specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
// USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

//
// Created by user on 11/10/23.
//

#include "devices/event.h"
#include "devices/device_handle.h"

using namespace rpy;
using namespace rpy::devices;

namespace rpy { namespace devices { namespace dtl {

template class RPY_DLL_EXPORT ObjectBase<EventInterface, Event>;

}}}

void Event::wait()
{
    if (impl()) { impl()->wait(); }
}

EventStatus Event::status() const
{
    if (!impl()) { return EventStatus::CompletedSuccessfully; }
    return impl()->status();
}

bool Event::is_user() const noexcept {
    if (impl()) { return impl()->is_user(); }
    return false;
}
void Event::set_status(EventStatus status)
{
    if (!impl()) {
        return;
    }

    if (!impl()->is_user()) {
        RPY_THROW(
                std::runtime_error,
                "cannot set the status of a non-user event"
        );
    }

    return impl()->set_status(status);
}

==> roughpy-0.2.0.tar.gz: roughpy-0.2.0/platform/src/devices/event.cpp <==
// Copyright (c) 2023 the RoughPy Developers. All rights reserved.
//
// Redistribution and use in source and binary forms, with or without modification,
// are permitted provided that the following conditions are met:
//
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright notice,
// this list of conditions and the following disclaimer in the documentation
// and/or other materials provided with the distribution.
//
// 3. Neither the name of the copyright holder nor the names of its contributors
// may be used to endorse or promote products derived from this software without
// specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
// USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

//
// Created by user on 11/10/23.
//

#include "devices/event.h"

#include <roughpy/core/check.h>
#include <roughpy/core/macros.h>

#include "devices/core.h"
#include "devices/device_object_base.h"

using namespace rpy;
using namespace rpy::devices;

namespace rpy { namespace devices { namespace dtl {

template class RPY_DLL_EXPORT ObjectBase<EventInterface, Event>;

}}}

void Event::wait()
{
    if (impl()) { impl()->wait(); }
}

EventStatus Event::status() const
{
    if (!impl()) { return EventStatus::CompletedSuccessfully; }
    return impl()->status();
}

bool Event::is_user() const noexcept {
    if (impl()) { return impl()->is_user(); }
    return false;
}
void Event::set_status(EventStatus status)
{
    if (!impl()) {
        return;
    }

    if (!impl()->is_user()) {
        RPY_THROW(
                std::runtime_error,
                "cannot set the status of a non-user event"
        );
    }

    return impl()->set_status(status);
}
